@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
+ *   Copyright (C) 2008-2018 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -274,6 +274,12 @@ AppSettings::AppSettings(QWidget * parent, Qt::WindowFlags f) : QDialog(parent,
     } else {
         cbEnableDesktopMenu->setChecked(false);
     }
+    if (settings.value("ExportSystemFolder", 0).toInt()==1){
+        cbExportSystemFolder->setChecked(true);
+    } else {
+        cbExportSystemFolder->setChecked(false);
+    }
+
     settings.endGroup();
     connect(cmdDesktopMenu_Regen, SIGNAL(clicked()), this, SLOT(cmdDesktopMenu_Regen_Click()));
     connect(cmdDesktopMenu_Remove, SIGNAL(clicked()), this, SLOT(cmdDesktopMenu_Remove_Click()));
@@ -702,6 +708,11 @@ void AppSettings::cmdOk_Click(){
     } else {
         settings.setValue("enableMenuDesktop", 0);
     }
+    if (cbExportSystemFolder->isChecked()){
+        settings.setValue("ExportSystemFolder", 1);
+    } else {
+        settings.setValue("ExportSystemFolder", 0);
+    }
     settings.endGroup();
 #endif
 
@@ -826,6 +837,22 @@ void AppSettings::cbShowTray_stateChanged ( int state ){
 }
 
 void AppSettings::cmdDesktopMenu_Regen_Click(){
+
+    //save changes in order to apply user-selected settings
+    QSettings settings(APP_SHORT_NAME, "default");
+    settings.beginGroup("Plugins");
+    if (cbEnableDesktopMenu->isChecked()){
+        settings.setValue("enableMenuDesktop", 1);
+    } else {
+        settings.setValue("enableMenuDesktop", 0);
+    }
+    if (cbExportSystemFolder->isChecked()){
+        settings.setValue("ExportSystemFolder", 1);
+    } else {
+        settings.setValue("ExportSystemFolder", 0);
+    }
+    settings.endGroup();
+
     system_menu sys_menu;
     sys_menu.create_dir_info();
     sys_menu.generateSystemMenu();
